@@ -3,12 +3,12 @@
  * NAGIOS.C - Core Program Code For Nagios
  *
  * Program: Nagios
- * Version: 2.11
+ * Version: 2.3
  * License: GPL
- * Copyright (c) 1999-2007 Ethan Galstad (http://www.nagios.org)
+ * Copyright (c) 1999-2006 Ethan Galstad (http://www.nagios.org)
  *
  * First Written:   01-28-1999 (start of development)
- * Last Modified:   03-12-2008
+ * Last Modified:   05-03-2006
  *
  * Description:
  *
@@ -142,9 +142,6 @@ int             log_rotation_method=LOG_ROTATION_NONE;
 
 int             sigshutdown=FALSE;
 int             sigrestart=FALSE;
-char            *sigs[35]={"EXIT","HUP","INT","QUIT","ILL","TRAP","ABRT","BUS","FPE","KILL","USR1","SEGV","USR2","PIPE","ALRM","TERM","STKFLT","CHLD","CONT","STOP","TSTP","TTIN","TTOU","URG","XCPU","XFSZ","VTALRM","PROF","WINCH","IO","PWR","UNUSED","ZERR","DEBUG",(char *)NULL};
-int             caught_signal=FALSE;
-int             sig_id=0;
 
 int             restarting=FALSE;
 
@@ -210,8 +207,6 @@ service_message svc_msg;
 circular_buffer  external_command_buffer;
 circular_buffer  service_result_buffer;
 pthread_t worker_threads[TOTAL_WORKER_THREADS];
-int              external_command_buffer_slots=DEFAULT_EXTERNAL_COMMAND_BUFFER_SLOTS;
-int              check_result_buffer_slots=DEFAULT_CHECK_RESULT_BUFFER_SLOTS;
 
 
 
@@ -226,7 +221,7 @@ int main(int argc, char **argv){
 	char buffer[MAX_INPUT_BUFFER];
 	int display_license=FALSE;
 	int display_help=FALSE;
-	int c=0,x=0;
+	int c;
 
 #ifdef HAVE_GETOPT_H
 	int option_index=0;
@@ -289,7 +284,7 @@ int main(int argc, char **argv){
 
 	if(daemon_mode==FALSE){
 		printf("\nNagios %s\n",PROGRAM_VERSION);
-		printf("Copyright (c) 1999-2007 Ethan Galstad (http://www.nagios.org)\n");
+		printf("Copyright (c) 1999-2006 Ethan Galstad (http://www.nagios.org)\n");
 		printf("Last Modified: %s\n",PROGRAM_MODIFICATION_DATE);
 		printf("License: GPL\n\n");
 	        }
@@ -714,24 +709,6 @@ int main(int argc, char **argv){
 			/* (doesn't return until a restart or shutdown signal is encountered) */
 			event_execution_loop();
 
-			/* 03/01/2007 EG Moved from sighandler() to prevent FUTEX locking problems under NPTL */
-			/* 03/21/2007 EG SIGSEGV signals are still logged in sighandler() so we don't loose them */
-			/* did we catch a signal? */
-			if(caught_signal==TRUE){
-
-				if(sig_id==SIGHUP)
-					snprintf(buffer,sizeof(buffer),"Caught SIGHUP, restarting...\n");
-				else if(sig_id!=SIGSEGV)
-					snprintf(buffer,sizeof(buffer),"Caught SIG%s, shutting down...\n",sigs[sig_id]);
-				buffer[sizeof(buffer)-1]='\x0';
-
-#ifdef DEBUG2
-				printf("%s\n",buffer);
-#endif
-
-				write_to_all_logs(buffer,NSLOG_PROCESS_INFO);
-				}
-
 #ifdef USE_EVENT_BROKER
 			/* send program data to broker */
 			broker_program_state(NEBTYPE_PROCESS_EVENTLOOPEND,NEBFLAG_NONE,NEBATTR_NONE,NULL);
