@@ -2,8 +2,8 @@
  *
  * CGIUTILS.C - Common utilities for Nagios CGIs
  * 
- * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 11-10-2007
+ * Copyright (c) 1999-2004 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 11-05-2004
  *
  * License:
  *
@@ -1178,9 +1178,9 @@ int mmap_fclose(mmapfile *temp_mmapfile){
 
 /* gets one line of input from an mmap()'ed file */
 char *mmap_fgets(mmapfile *temp_mmapfile){
-	char *buf=NULL;
-	unsigned long x=0L;
-	int len=0;
+	char *buf;
+	unsigned long x;
+	int len;
 
 	if(temp_mmapfile==NULL)
 		return NULL;
@@ -1191,25 +1191,23 @@ char *mmap_fgets(mmapfile *temp_mmapfile){
 
 	/* find the end of the string (or buffer) */
 	for(x=temp_mmapfile->current_position;x<temp_mmapfile->file_size;x++){
-		if(*((char *)(temp_mmapfile->mmap_buf)+x)=='\n'){
-			x++;
+		if(*(char *)(temp_mmapfile->mmap_buf+x)=='\n')
 			break;
-			}
 	        }
 
 	/* calculate length of line we just read */
-	len=(int)(x-temp_mmapfile->current_position);
+	len=(int)x-temp_mmapfile->current_position+1;
 
 	/* allocate memory for the new line */
 	if((buf=(char *)malloc(len+1))==NULL)
 		return NULL;
 
 	/* copy string to newly allocated memory and terminate the string */
-	memcpy(buf,((char *)(temp_mmapfile->mmap_buf)+temp_mmapfile->current_position),len);
+	memcpy(buf,(char *)(temp_mmapfile->mmap_buf+temp_mmapfile->current_position),len);
 	buf[len]='\x0';
 
 	/* update the current position */
-	temp_mmapfile->current_position=x;
+	temp_mmapfile->current_position=x+1;
 
 	/* increment the current line */
 	temp_mmapfile->current_line++;
@@ -1345,7 +1343,7 @@ char * url_encode(char *input){
 char * html_encode(char *input){
 	int len,output_len;
 	int x,y;
-	char temp_expansion[10];
+	char temp_expansion[7];
 
 	len=(int)strlen(input);
 	output_len=(int)sizeof(encoded_html_string);
@@ -1366,9 +1364,8 @@ char * html_encode(char *input){
 			y++;
 		        }
 
-#ifdef NOT_SO_SURE_ABOUT_THIS
 		/* spaces are encoded as non-breaking spaces */
-		else if((char)input[x]==(char)' '){
+		else if((char)input[x]<=(char)' '){
 
 			encoded_html_string[y]='\x0';
 			if((int)strlen(encoded_html_string)<(output_len-6)){
@@ -1376,30 +1373,11 @@ char * html_encode(char *input){
 				y+=6;
 			        }
 		        }
-#endif
-
-		else if((char)input[x]==(char)'<'){
-
-			encoded_html_string[y]='\x0';
-			if((int)strlen(encoded_html_string)<(output_len-4)){
-				strcat(encoded_html_string,"&lt;");
-				y+=4;
-			        }
-		        }
-
-		else if((char)input[x]==(char)'>'){
-
-			encoded_html_string[y]='\x0';
-			if((int)strlen(encoded_html_string)<(output_len-4)){
-				strcat(encoded_html_string,"&gt;");
-				y+=4;
-			        }
-		        }
 
 		/* for simplicity, everything else gets represented by its numeric value */
 		else{
 			encoded_html_string[y]='\x0';
-			sprintf(temp_expansion,"&#%d;",(unsigned char)input[x]);
+			sprintf(temp_expansion,"&#%d;",(unsigned int)input[x]);
 			if((int)strlen(encoded_html_string)<(output_len-strlen(temp_expansion))){
 				strcat(encoded_html_string,temp_expansion);
 				y+=strlen(temp_expansion);
@@ -1414,30 +1392,6 @@ char * html_encode(char *input){
 
 
 
-
-/* strip > and < from string */
-void strip_html_brackets(char *buffer){
-	register int x;
-	register int y;
-	register int z;
-
-	if(buffer==NULL || buffer[0]=='\x0')
-		return;
-
-	/* remove all occurances in string */
-	z=(int)strlen(buffer);
-	for(x=0,y=0;x<z;x++){
-		if(buffer[x]=='<' || buffer[x]=='>')
-			continue;
-		buffer[y++]=buffer[x];
-	        }
-	buffer[y++]='\x0';
-
-	return;
-	}
-
-
-
 /* determines the log file we should use (from current time) */
 void get_log_archive_to_use(int archive,char *buffer,int buffer_length){
 	struct tm *t;
@@ -1605,7 +1559,7 @@ void display_info_table(char *title,int refresh, authdata *current_authdata){
 	int result;
 
 	/* read program status */
-	result=read_all_status_data(get_cgi_config_location(),READ_PROGRAM_STATUS);
+	result=read_all_status_data(DEFAULT_CGI_CONFIG_FILE,READ_PROGRAM_STATUS);
 
 	printf("<TABLE CLASS='infoBox' BORDER=1 CELLSPACING=0 CELLPADDING=0>\n");
 	printf("<TR><TD CLASS='infoBox'>\n");
@@ -1618,7 +1572,7 @@ void display_info_table(char *title,int refresh, authdata *current_authdata){
 	if(refresh==TRUE)
 		printf("Updated every %d seconds<br>\n",refresh_rate);
 
-	printf("Nagios&reg; %s - <A HREF='http://www.nagios.org' TARGET='_new' CLASS='homepageURL'>www.nagios.org</A><BR>\n",PROGRAM_VERSION);
+	printf("Nagios&reg; - <A HREF='http://www.nagios.org' TARGET='_new' CLASS='homepageURL'>www.nagios.org</A><BR>\n");
 
 	if(current_authdata!=NULL)
 		printf("Logged in as <i>%s</i><BR>\n",(!strcmp(current_authdata->username,""))?"?":current_authdata->username);
