@@ -2,8 +2,8 @@
  *
  * NOTIFICATIONS.C - Nagios Notifications CGI
  *
- * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 11-10-2007
+ * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 03-21-2006
  *
  * This CGI program will display the notification events for 
  * a given host or contact or for all contacts/hosts.
@@ -154,7 +154,7 @@ int main(void){
 				printf("<A HREF='%s?host=%s'>View History For %s</A><BR>\n",HISTORY_CGI,(find_all==TRUE)?"all":url_encode(query_host_name),(find_all==TRUE)?"All Hosts":"This Host");
 #ifdef USE_TRENDS
 				if(find_all==FALSE)
-					printf("<A HREF='%s?host=%s'>View Trends For This Host</A><BR>\n",TRENDS_CGI,url_encode(query_host_name));
+					printf("<A HREF='%s?host=%s'>View Trends For This Host</A><BR>\n",HISTORY_CGI,url_encode(query_host_name));
 #endif
 	                        }
 			else if(query_type==FIND_SERVICE){
@@ -371,7 +371,6 @@ int process_cgivars(void){
 			query_host_name=strdup(variables[x]);
 			if(query_host_name==NULL)
 				query_host_name="";
-			strip_html_brackets(query_host_name);
 			if(!strcmp(query_host_name,"all"))
 				find_all=TRUE;
 			else
@@ -391,8 +390,6 @@ int process_cgivars(void){
 
 			if(query_contact_name==NULL)
 				query_contact_name="";
-			strip_html_brackets(query_contact_name);
-
 			if(!strcmp(query_contact_name,"all"))
 				find_all=TRUE;
 			else
@@ -411,7 +408,6 @@ int process_cgivars(void){
 			query_svc_description=strdup(variables[x]);
 			if(query_svc_description==NULL)
 				query_svc_description="";
-			strip_html_brackets(query_svc_description);
 		        }
 	
 		/* we found the notification type argument */
@@ -557,7 +553,7 @@ void display_notifications(void){
 			/* get the host name */
 			temp_buffer=(char *)strtok(NULL,";");
 			snprintf(host_name,sizeof(host_name),"%s",(temp_buffer==NULL)?"":temp_buffer);
-			host_name[sizeof(host_name)-1]='\x0';
+			host_name[sizeof(host_name)]='\x0';
 
 			/* get the service name */
 			if(notification_type==SERVICE_NOTIFICATION){
@@ -718,7 +714,7 @@ void display_notifications(void){
 				printf("<td CLASS='notifications%s'>%s</td>\n",(odd)?"Even":"Odd",date_time);
 				printf("<td CLASS='notifications%s'><a href='%s?type=contacts#%s'>%s</a></td>\n",(odd)?"Even":"Odd",CONFIG_CGI,url_encode(contact_name),contact_name);
 				printf("<td CLASS='notifications%s'><a href='%s?type=commands#%s'>%s</a></td>\n",(odd)?"Even":"Odd",CONFIG_CGI,url_encode(method_name),method_name);
-				printf("<td CLASS='notifications%s'>%s</td>\n",(odd)?"Even":"Odd",html_encode(temp_buffer));
+				printf("<td CLASS='notifications%s'>%s</td>\n",(odd)?"Even":"Odd",temp_buffer);
 				printf("</tr>\n");
 			        }
 		        }
