@@ -2,8 +2,8 @@
  *
  * XSDDEFAULT.C - Default external status data input routines for Nagios
  *
- * Copyright (c) 2000-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   10-19-2007
+ * Copyright (c) 2000-2005 Ethan Galstad (nagios@nagios.org)
+ * Last Modified:   11-25-2005
  *
  * License:
  *
@@ -85,12 +85,6 @@ extern int enable_flap_detection;
 extern int enable_failure_prediction;
 extern int process_performance_data;
 extern int aggregate_status_updates;
-extern int check_external_commands;
-
-extern int external_command_buffer_slots;
-extern int check_result_buffer_slots;
-extern circular_buffer external_command_buffer;
-extern circular_buffer service_result_buffer;
 
 extern char *macro_x[MACRO_X_COUNT];
 
@@ -301,10 +295,6 @@ int xsddefault_save_status_data(void){
 	time_t current_time;
 	int fd=0;
 	FILE *fp=NULL;
-	int used_check_result_buffer_slots=0;
-	int high_check_result_buffer_slots=0;
-	int used_external_command_buffer_slots=0;
-	int high_external_command_buffer_slots=0;
 
 	/* open a safe temp file for output */
 	snprintf(xsddefault_aggregate_temp_file,sizeof(xsddefault_aggregate_temp_file)-1,"%sXXXXXX",xsddefault_temp_file);
@@ -332,24 +322,6 @@ int xsddefault_save_status_data(void){
 		return ERROR;
 	        }
 
-	/* get number of items in the check result buffer */
-	pthread_mutex_lock(&service_result_buffer.buffer_lock);
-	used_check_result_buffer_slots=service_result_buffer.items;
-	high_check_result_buffer_slots=service_result_buffer.high;
-	pthread_mutex_unlock(&service_result_buffer.buffer_lock);
-
-	/* get number of items in the command buffer */
-	if(check_external_commands==TRUE){
-		pthread_mutex_lock(&external_command_buffer.buffer_lock);
-		used_external_command_buffer_slots=external_command_buffer.items;
-		high_external_command_buffer_slots=external_command_buffer.high;
-		pthread_mutex_unlock(&external_command_buffer.buffer_lock);
-		}
-	else{
-		used_external_command_buffer_slots=0;
-		high_external_command_buffer_slots=0;
-		}
-
 	/* write version info to status file */
 	fprintf(fp,"########################################\n");
 	fprintf(fp,"#          NAGIOS STATUS FILE\n");
@@ -390,12 +362,6 @@ int xsddefault_save_status_data(void){
 	fprintf(fp,"\tprocess_performance_data=%d\n",process_performance_data);
 	fprintf(fp,"\tglobal_host_event_handler=%s\n",(global_host_event_handler==NULL)?"":global_host_event_handler);
 	fprintf(fp,"\tglobal_service_event_handler=%s\n",(global_service_event_handler==NULL)?"":global_service_event_handler);
-	fprintf(fp,"\ttotal_external_command_buffer_slots=%d\n",external_command_buffer_slots);
-	fprintf(fp,"\tused_external_command_buffer_slots=%d\n",used_external_command_buffer_slots);
-	fprintf(fp,"\thigh_external_command_buffer_slots=%d\n",high_external_command_buffer_slots);
-	fprintf(fp,"\ttotal_check_result_buffer_slots=%d\n",check_result_buffer_slots);
-	fprintf(fp,"\tused_check_result_buffer_slots=%d\n",used_check_result_buffer_slots);
-	fprintf(fp,"\thigh_check_result_buffer_slots=%d\n",high_check_result_buffer_slots);
 	fprintf(fp,"\t}\n\n");
 
 
@@ -542,13 +508,8 @@ int xsddefault_save_status_data(void){
 
 /* read all program, host, and service status information */
 int xsddefault_read_status_data(char *config_file,int options){
-#ifdef BAD_MMAP
 	char *input=NULL;
 	mmapfile *thefile;
-#else
-	char input[2048]="";
-	FILE *fp=NULL;
-#endif
 	int data_type=XSDDEFAULT_NO_DATA;
 	hoststatus *temp_hoststatus=NULL;
 	servicestatus *temp_servicestatus=NULL;
@@ -562,29 +523,18 @@ int xsddefault_read_status_data(char *config_file,int options){
 		return ERROR;
 
 	/* open the status file for reading */
-#ifdef BAD_MMAP
 	if((thefile=mmap_fopen(xsddefault_status_log))==NULL)
 		return ERROR;
-#else
-	if((fp=fopen(xsddefault_status_log,"r"))==NULL)
-		return ERROR;
-#endif
 
 	/* read all lines in the status file */
 	while(1){
 
-#ifdef BAD_MMAP
 		/* free memory */
 		free(input);
 
 		/* read the next line */
 		if((input=mmap_fgets(thefile))==NULL)
 			break;
-#else
-		strcpy(input,"");
-		if(fgets(input,sizeof(input),fp)==NULL)
-			break;
-#endif
 
 		strip(input);
 
@@ -889,12 +839,8 @@ int xsddefault_read_status_data(char *config_file,int options){
 	        }
 
 	/* free memory and close the file */
-#ifdef BAD_MMAP
 	free(input);
 	mmap_fclose(thefile);
-#else
-	fclose(fp);
-#endif
 
 	return OK;
         }
